@@ -284,7 +284,15 @@ if command -v docker &>/dev/null; then
     show_success "Docker가 이미 설치되어 있습니다"
     sudo systemctl start docker 2>/dev/null || true
     sudo systemctl enable docker 2>/dev/null || true
-    sudo usermod -aG docker $USER 2>/dev/null || true
+
+    # 사용자를 docker 그룹에 추가
+    if ! groups $USER | grep -q docker; then
+        show_info "사용자를 docker 그룹에 추가 중..."
+        sudo usermod -aG docker $USER 2>/dev/null || true
+        show_warning "Docker 그룹 권한은 재로그인 후 적용됩니다"
+    else
+        show_success "사용자가 이미 docker 그룹에 속해 있습니다"
+    fi
 else
     show_warning "Docker가 설치되지 않았습니다. Docker를 수동으로 설치해주세요."
     show_info "Docker 설치 방법: https://docs.docker.com/engine/install/"
@@ -501,9 +509,7 @@ else
     handle_error "requirements-linux.txt 파일을 찾을 수 없습니다"
 fi
 
-# Install additional packages
-show_info "추가 패키지 설치 중..."
-"$VENV_PATH/bin/pip" install pyhwpx python-docx || true
+# python-docx는 requirements-linux.txt에 이미 포함되어 있음
 
 # Ensure sentence-transformers is updated for PyTorch 2.8
 "$VENV_PATH/bin/pip" install --upgrade sentence-transformers || true
@@ -642,11 +648,89 @@ export RAG_MODE=fast
 EOF
 show_success "airun.conf 생성 완료"
 
+# Clean npm cache and configuration
+show_info "npm 캐시 정리 및 설정 중..."
+rm -rf node_modules package-lock.json 2>/dev/null || true
+npm cache clean --force 2>/dev/null || true
+
+# Change npm configuration
+npm config set ignore-scripts false
+npm config set legacy-peer-deps true
+
 # Install local npm packages
 show_info "로컬 npm 패키지 설치 중..."
 npm install --legacy-peer-deps || handle_error "npm 패키지 설치 실패"
 show_success "npm 패키지 설치 완료"
 
+# Create global airun command link
+show_info "전역 airun 명령어 링크 생성 중..."
+
+# Ensure index.js is executable BEFORE npm link
+chmod +x "$CURRENT_DIR/index.js" || handle_error "index.js 실행권한 설정 실패"
+
+# Remove existing global links if they exist
+AIRUN_PATH=$(which airun 2>/dev/null || echo "")
+if [ -n "$AIRUN_PATH" ]; then
+    show_warning "기존 airun 링크 발견: $AIRUN_PATH"
+    # Remove existing npm global links
+    npm unlink airun 2>/dev/null || true
+    npm uninstall -g airun 2>/dev/null || true
+fi
+
+# Create npm global link (after setting permissions)
+cd "$CURRENT_DIR"
+npm link || handle_error "npm link 실패"
+npm link electron 2>/dev/null || show_warning "electron link 실패 (선택적)"
+
+# Verify the link was created
+LINK_PATH=$(which airun 2>/dev/null || echo "")
+if [ -n "$LINK_PATH" ]; then
+    if [ -L "$LINK_PATH" ]; then
+        LINK_TARGET=$(readlink -f "$LINK_PATH" 2>/dev/null || readlink "$LINK_PATH")
+        if [ "$LINK_TARGET" = "$CURRENT_DIR/index.js" ]; then
+            show_success "전역 airun 명령어 링크 생성 완료: $LINK_PATH"
+
+            # Ensure proper permissions for the target file
+            chmod +x "$CURRENT_DIR/index.js" 2>/dev/null || true
+
+            # Ensure the current user can access the directory
+            chmod 755 "$CURRENT_DIR" 2>/dev/null || true
+
+            # If link is in system path, note but don't require sudo
+            if [[ "$LINK_PATH" == /usr/local/bin/* ]]; then
+                show_info "시스템 경로에 링크됨: $LINK_PATH (관리자 권한으로 설치됨)"
+            fi
+
+        else
+            show_warning "링크가 올바른 경로를 가리키지 않음 (예상: $CURRENT_DIR/index.js, 실제: $LINK_TARGET)"
+        fi
+    else
+        show_success "전역 airun 명령어 설치 완료: $LINK_PATH"
+        # Ensure binary is executable
+        chmod +x "$LINK_PATH" 2>/dev/null || true
+    fi
+
+    # Test if the command is accessible
+    if command -v airun >/dev/null 2>&1; then
+        show_success "airun 명령어 접근 가능 확인됨"
+    else
+        show_warning "airun 명령어 접근 불가 - PATH 환경변수 확인 필요"
+
+        # Add to PATH if needed
+        NPM_PREFIX=$(npm config get prefix 2>/dev/null || echo "/usr/local")
+        NPM_BIN_PATH="$NPM_PREFIX/bin"
+
+        if [[ ":$PATH:" != *":$NPM_BIN_PATH:"* ]]; then
+            show_info "PATH에 $NPM_BIN_PATH 추가 중..."
+            echo 'export PATH="'$NPM_BIN_PATH':$PATH"' >> ~/.bashrc
+            echo 'export PATH="'$NPM_BIN_PATH':$PATH"' >> ~/.zshrc 2>/dev/null || true
+            show_success "PATH 설정 완료 (새 터미널에서 적용)"
+        fi
+    fi
+else
+    show_warning "airun 명령어 링크 확인 실패 (수동 확인 필요)"
+fi
+
 show_success "PHASE 6 완료: 설정 파일 생성 완료"
 
 #############################################
@@ -926,25 +1010,49 @@ echo ""
 
 # 1. Check PostgreSQL
 show_info "PostgreSQL 확인..."
-if sudo docker ps | grep -q airun_postgres; then
-    # Check connection
-    if PGPASSWORD=1234 psql -h localhost -p 5433 -U ivs -d airun -c "\l" >/dev/null 2>&1; then
-        show_success "PostgreSQL: 실행 중 (포트 5433)"
-        # Check pgvector extension
-        if PGPASSWORD=1234 psql -h localhost -p 5433 -U ivs -d airun -c "SELECT * FROM pg_extension WHERE extname='vector';" | grep -q vector; then
-            show_success "pgvector 확장: 활성화됨"
+
+# Docker 그룹 권한 적용을 위해 새 그룹 세션에서 실행
+check_postgres() {
+    # 현재 사용자가 docker 그룹에 속해있는지 확인
+    if groups $USER | grep -q docker; then
+        # 그룹 권한이 있으면 sudo 없이 시도
+        if docker ps 2>/dev/null | grep -q airun_postgres; then
+            DOCKER_ACCESS=true
         else
-            show_warning "pgvector 확장: 비활성화"
+            DOCKER_ACCESS=false
+        fi
+    else
+        # 그룹 권한이 없으면 sudo 사용
+        if sudo docker ps | grep -q airun_postgres; then
+            DOCKER_ACCESS=true
+        else
+            DOCKER_ACCESS=false
+        fi
+    fi
+
+    if [ "$DOCKER_ACCESS" = true ]; then
+        # Check connection
+        if PGPASSWORD=1234 psql -h localhost -p 5433 -U ivs -d airun -c "\l" >/dev/null 2>&1; then
+            show_success "PostgreSQL: 실행 중 (포트 5433)"
+            # Check pgvector extension
+            if PGPASSWORD=1234 psql -h localhost -p 5433 -U ivs -d airun -c "SELECT * FROM pg_extension WHERE extname='vector';" | grep -q vector; then
+                show_success "pgvector 확장: 활성화됨"
+            else
+                show_warning "pgvector 확장: 비활성화"
+                ((WARNINGS++))
+            fi
+        else
+            show_warning "PostgreSQL: 연결 실패 (재로그인 후 확인 필요)"
+            show_info "Docker 그룹 권한이 현재 세션에 적용되지 않았을 수 있습니다"
             ((WARNINGS++))
         fi
     else
-        show_warning "PostgreSQL: 연결 실패"
+        show_warning "PostgreSQL Docker: 실행 안됨"
         ((ERRORS++))
     fi
-else
-    show_warning "PostgreSQL Docker: 실행 안됨"
-    ((ERRORS++))
-fi
+}
+
+check_postgres
 
 # 2. Check Redis
 show_info "Redis 확인..."
