@@ -88,6 +88,19 @@ const configGroups = [
       'USE_SMTP',
     ],
   },
+  {
+    name: 'database',
+    title: '데이터베이스',
+    keys: [
+      'DB_HOST',
+      'DB_PORT',
+      'DB_USER',
+      'DB_PASSWORD',
+      'DB_NAME',
+      'DB_POOL_MAX_SIZE',
+      'DB_POOL_MIN_SIZE',
+    ],
+  },
   {
     name: 'path',
     title: '시스템',
@@ -126,7 +139,12 @@ const configGroups = [
 ];
 
 // 항목별 타입/설명 매핑 (실제 conf에 있는 값만)
-const configMeta: Record<string, { label: string; type: 'string' | 'number' | 'boolean' | 'password' }> = {
+const configMeta: Record<string, {
+  label: string;
+  type: 'string' | 'number' | 'boolean' | 'password';
+  readonly?: boolean;
+  description?: string;
+}> = {
   OPENAI_API_KEY: { label: 'OpenAI API 키', type: 'password' },
   OPENAI_MODEL: { label: 'OpenAI 모델', type: 'string' },
   ANTHROPIC_API_KEY: { label: 'Anthropic API 키', type: 'password' },
@@ -136,6 +154,14 @@ const configMeta: Record<string, { label: string; type: 'string' | 'number' | 'b
   GROQ_API_KEY: { label: 'Groq API 키', type: 'password' },
   GROQ_MODEL: { label: 'Groq 모델', type: 'string' },
   OLLAMA_MODEL: { label: 'Ollama 모델', type: 'string' },
+  // 데이터베이스 설정
+  DB_HOST: { label: '데이터베이스 호스트', type: 'string', readonly: true, description: '시스템 설정으로 변경 불가' },
+  DB_PORT: { label: '데이터베이스 포트', type: 'number', readonly: true, description: '시스템 설정으로 변경 불가' },
+  DB_USER: { label: '데이터베이스 사용자', type: 'string', description: '새 사용자명을 입력하면 PostgreSQL에 자동 생성됩니다' },
+  DB_PASSWORD: { label: '데이터베이스 비밀번호', type: 'password', description: '실제 PostgreSQL 사용자 비밀번호가 변경됩니다' },
+  DB_NAME: { label: '데이터베이스 이름', type: 'string', readonly: true, description: '시스템 설정으로 변경 불가' },
+  DB_POOL_MAX_SIZE: { label: '최대 연결 수', type: 'number', readonly: true, description: '시스템 설정으로 변경 불가' },
+  DB_POOL_MIN_SIZE: { label: '최소 연결 수', type: 'number', readonly: true, description: '시스템 설정으로 변경 불가' },
   VLLM_MODEL: { label: 'VLLM 모델', type: 'string' },
   NEXT_PUBLIC_VLLM_SERVER: { label: 'VLLM 서버', type: 'string' },
   RAG_CHUNK_OVERLAP: { label: '청크 오버랩', type: 'number' },
@@ -217,6 +243,8 @@ function getSaveButtonStyle(groupName: string) {
       return { text: '시스템 설정 저장', bg: '#3B82F6', textColor: 'white' }; // blue-500
     case 'feature':
       return { text: '서비스 설정 저장', bg: '#3B82F6', textColor: 'white' }; // blue-500
+    case 'database':
+      return { text: '데이터베이스 설정 저장', bg: '#059669', textColor: 'white' }; // emerald-600
     default:
       return { text: '설정 저장', bg: '#3B82F6', textColor: 'white' }; // blue-500
   }
@@ -1429,6 +1457,9 @@ export default function SettingsPage() {
             <div key={key} className="mb-2">
               <label className="block text-base font-medium mb-1">{meta.label}</label>
               {renderInput(key, editedConfigs[key], meta)}
+              {meta.description && (
+                <p className="text-xs text-gray-500 mt-1">{meta.description}</p>
+              )}
             </div>
           );
         })}
@@ -1481,12 +1512,15 @@ export default function SettingsPage() {
             type="number"
             value={value ?? ''}
             onChange={(e) => handleConfigChange(key, e.target.value)}
-            className="w-full border rounded px-3 py-2 transition"
-            style={{ 
-              borderColor: 'var(--card-border)', 
-              backgroundColor: 'var(--card-bg)', 
-              color: 'var(--text-primary)' 
+            readOnly={configMeta[key]?.readonly}
+            disabled={configMeta[key]?.readonly}
+            className={`w-full border rounded px-3 py-2 transition ${configMeta[key]?.readonly ? 'cursor-not-allowed opacity-60' : ''}`}
+            style={{
+              borderColor: 'var(--card-border)',
+              backgroundColor: configMeta[key]?.readonly ? 'var(--bg-secondary)' : 'var(--card-bg)',
+              color: configMeta[key]?.readonly ? 'var(--text-muted)' : 'var(--text-primary)'
             }}
+            title={configMeta[key]?.readonly ? configMeta[key]?.description : undefined}
           />
         );
       case 'password':
@@ -1496,30 +1530,35 @@ export default function SettingsPage() {
               type={showApiKey[key] ? 'text' : 'password'}
               value={value ?? ''}
               onChange={(e) => handleConfigChange(key, e.target.value)}
-              className="flex-1 border rounded px-3 py-2 transition"
-              style={{ 
-                borderColor: 'var(--card-border)', 
-                backgroundColor: 'var(--card-bg)', 
-                color: 'var(--text-primary)' 
+              readOnly={configMeta[key]?.readonly}
+              disabled={configMeta[key]?.readonly}
+              className={`flex-1 border rounded px-3 py-2 transition ${configMeta[key]?.readonly ? 'cursor-not-allowed opacity-60' : ''}`}
+              style={{
+                borderColor: 'var(--card-border)',
+                backgroundColor: configMeta[key]?.readonly ? 'var(--bg-secondary)' : 'var(--card-bg)',
+                color: configMeta[key]?.readonly ? 'var(--text-muted)' : 'var(--text-primary)'
               }}
               placeholder="••••••••"
+              title={configMeta[key]?.readonly ? configMeta[key]?.description : undefined}
             />
-            <button
-              type="button"
-              aria-label={showApiKey[key] ? 'API 키 숨기기' : 'API 키 보기'}
-              className="hover:opacity-80 transition-opacity"
-              style={{ background: 'none', border: 'none', padding: 0, color: 'var(--text-muted)' }}
-              tabIndex={0}
-              onClick={() => setShowApiKey((prev) => ({ ...prev, [key]: !prev[key] }))}
-              onMouseEnter={(e) => e.currentTarget.style.color = 'var(--text-primary)'}
-              onMouseLeave={(e) => e.currentTarget.style.color = 'var(--text-muted)'}
-            >
-              {showApiKey[key] ? (
-                <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" fill="none" viewBox="0 0 24 24" stroke="currentColor"><path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M13.875 18.825A10.05 10.05 0 0112 19c-5.523 0-10-4.477-10-10 0-1.657.403-3.22 1.125-4.575m1.664-2.13A9.956 9.956 0 0112 3c5.523 0 10 4.477 10 10 0 2.21-.715 4.254-1.925 5.925M15 12a3 3 0 11-6 0 3 3 0 016 0z" /></svg>
-              ) : (
-                <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" fill="none" viewBox="0 0 24 24" stroke="currentColor"><path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M15 12a3 3 0 11-6 0 3 3 0 016 0z" /><path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M2.458 12C3.732 7.943 7.523 5 12 5c4.477 0 8.268 2.943 9.542 7-.274.832-.64 1.624-1.09 2.357" /></svg>
-              )}
-            </button>
+            {!configMeta[key]?.readonly && (
+              <button
+                type="button"
+                aria-label={showApiKey[key] ? 'API 키 숨기기' : 'API 키 보기'}
+                className="hover:opacity-80 transition-opacity"
+                style={{ background: 'none', border: 'none', padding: 0, color: 'var(--text-muted)' }}
+                tabIndex={0}
+                onClick={() => setShowApiKey((prev) => ({ ...prev, [key]: !prev[key] }))}
+                onMouseEnter={(e) => e.currentTarget.style.color = 'var(--text-primary)'}
+                onMouseLeave={(e) => e.currentTarget.style.color = 'var(--text-muted)'}
+              >
+                {showApiKey[key] ? (
+                  <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" fill="none" viewBox="0 0 24 24" stroke="currentColor"><path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M13.875 18.825A10.05 10.05 0 0112 19c-5.523 0-10-4.477-10-10 0-1.657.403-3.22 1.125-4.575m1.664-2.13A9.956 9.956 0 0112 3c5.523 0 10 4.477 10 10 0 2.21-.715 4.254-1.925 5.925M15 12a3 3 0 11-6 0 3 3 0 016 0z" /></svg>
+                ) : (
+                  <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" fill="none" viewBox="0 0 24 24" stroke="currentColor"><path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M15 12a3 3 0 11-6 0 3 3 0 016 0z" /><path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M2.458 12C3.732 7.943 7.523 5 12 5c4.477 0 8.268 2.943 9.542 7-.274.832-.64 1.624-1.09 2.357" /></svg>
+                )}
+              </button>
+            )}
           </div>
         );
       case 'string':
@@ -1611,12 +1650,15 @@ export default function SettingsPage() {
             type="text"
             value={value ?? ''}
             onChange={(e) => handleConfigChange(key, e.target.value)}
-            className="w-full border rounded px-3 py-2 transition"
-            style={{ 
-              borderColor: 'var(--card-border)', 
-              backgroundColor: 'var(--card-bg)', 
-              color: 'var(--text-primary)' 
+            readOnly={configMeta[key]?.readonly}
+            disabled={configMeta[key]?.readonly}
+            className={`w-full border rounded px-3 py-2 transition ${configMeta[key]?.readonly ? 'cursor-not-allowed opacity-60' : ''}`}
+            style={{
+              borderColor: 'var(--card-border)',
+              backgroundColor: configMeta[key]?.readonly ? 'var(--bg-secondary)' : 'var(--card-bg)',
+              color: configMeta[key]?.readonly ? 'var(--text-muted)' : 'var(--text-primary)'
             }}
+            title={configMeta[key]?.readonly ? configMeta[key]?.description : undefined}
           />
         );
       default:
